| get_avesdata_repo | R Documentation |
Pull down full AvesData repository to a working directory
get_avesdata_repo(path, overwrite = FALSE)
path |
Path to download data zipfile to, and where it will be unpacked. To download into your working directory, use "." |
overwrite |
Default to |
Will download full data repo from https://github.com/McTavishLab/AvesData.
This data is required to use sampleTrees() to sample from the distribution of dated trees,
or to access earlier versions of the complete tree.
This function will download the data and set an environmental variable AVESDATA_PATH to the location of the data download.
When AVESDATA_PATH is set, the data_path in any clootl functions with a data_path argument will default to this value.
To manually set AVESDATA_PATH to the location of your downloaded AvesData repo use set_avesdata_repo_path()
No return value. This function is used to download the Aves Data repository.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.