set_avesdata_repo_path: Set path to Aves Data folder

View source: R/utils.R

set_avesdata_repo_pathR Documentation

Set path to Aves Data folder

Description

Set path to Aves Data folder already somewhere on your computer

Usage

set_avesdata_repo_path(path, overwrite = FALSE, warn = TRUE)

Arguments

path

A character vector with the path to the Aves Data folder

overwrite

Boolean, default to FALSE, does not overwrite an existing Aves Data folder. Set to TRUE to overwrite.

warn

Boolean, default to TRUE, Warns if path does not exist. Set to FALSE and path="" to unset path.

Details

Based on https://github.com/CornellLabofOrnithology/auk/blob/main/R/auk-set-ebd-path.r Use this function to manually set or update location of a downloaded AvesData folder from https://github.com/McTavishLab/AvesData. When AVESDATA_PATH is set, the data_path in any clootl functions with a data_path argument will default to this value.

Value

No return value, called to set the path to the Aves Data folder.

Examples

## Not run: 
set_avesdata_repo_path("/home/ejmctavish/AvesData")

## End(Not run)

clootl documentation built on April 24, 2026, 1:07 a.m.