| set_avesdata_repo_path | R Documentation |
Set path to Aves Data folder already somewhere on your computer
set_avesdata_repo_path(path, overwrite = FALSE, warn = TRUE)
path |
A character vector with the path to the Aves Data folder |
overwrite |
Boolean, default to |
warn |
Boolean, default to |
Based on https://github.com/CornellLabofOrnithology/auk/blob/main/R/auk-set-ebd-path.r
Use this function to manually set or update location of a downloaded AvesData folder from https://github.com/McTavishLab/AvesData.
When AVESDATA_PATH is set, the data_path in any clootl functions with a data_path argument will default to this value.
No return value, called to set the path to the Aves Data folder.
## Not run:
set_avesdata_repo_path("/home/ejmctavish/AvesData")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.