set_avesdata_repo_path: Set path to Aves Data folder
Description
Set path to Aves Data folder already somewhere on your computer
Usage
set_avesdata_repo_path(path, overwrite = FALSE)
Value
No return value, called to set the path to the Aves Data folder.
Arguments
path
A character vector with the path to the Aves Data folder.
overwrite
Boolean, default to FALSE, does not overwrite an existing Aves Data folder. Set to TRUE to overwrite.
Details
Based on https://github.com/CornellLabofOrnithology/auk/blob/main/R/auk-set-ebd-path.r
Use this function to manually set or update location of a downloaded AvesData folder from https://github.com/McTavishLab/AvesData.
When AVESDATA_PATH is set, the data_path in any clootl functions with a data_path argument will default to this value.